from ._base import Base
from typing import Any, BinaryIO

__all__ = ["Reactions"]


class Reactions(Base):

    def save_reaction(self, options: Any):
        """Create a reaction
        `Read in Mattermost API docs (reactions - SaveReaction) <https://developers.mattermost.com/api-documentation/#/operations/SaveReaction>`_

        """
        return self.client.post("""/api/v4/reactions""", options=options)

    def get_reactions(self, post_id: str):
        """Get a list of reactions to a post

        post_id: ID of a post

        `Read in Mattermost API docs (reactions - GetReactions) <https://developers.mattermost.com/api-documentation/#/operations/GetReactions>`_

        """
        return self.client.get(f"/api/v4/posts/{post_id}/reactions")

    def delete_reaction(self, user_id: str, post_id: str, emoji_name: str):
        """Remove a reaction from a post

        user_id: ID of the user
        post_id: ID of the post
        emoji_name: emoji name

        `Read in Mattermost API docs (reactions - DeleteReaction) <https://developers.mattermost.com/api-documentation/#/operations/DeleteReaction>`_

        """
        return self.client.delete(f"/api/v4/users/{user_id}/posts/{post_id}/reactions/{emoji_name}")

    def get_bulk_reactions(self, options: list[str]):
        """Bulk get the reaction for posts
        `Read in Mattermost API docs (reactions - GetBulkReactions) <https://developers.mattermost.com/api-documentation/#/operations/GetBulkReactions>`_

        """
        return self.client.post("""/api/v4/posts/ids/reactions""", options=options)



from ._base import Base

__all__ = ["Metrics"]


class Metrics(Base):

    def submit_performance_report(self, options=None):
        """Report client performance metrics

        version: An identifier for the schema of the data being submitted which currently must be "0.1.0"
        client_id: Not currently used
        labels: Labels to be applied to all metrics when recorded by the metrics backend
        start: The time in milliseconds of the first metric in this report
        end: The time in milliseconds of the last metric in this report
        counters: An array of counter metrics to be reported
        histograms: An array of histogram measurements to be reported

        `Read in Mattermost API docs (metrics - SubmitPerformanceReport) <https://developers.mattermost.com/api-documentation/#/operations/SubmitPerformanceReport>`_

        """
        return self.client.post("""/api/v4/client_perf""", options=options)



from ._base import Base

__all__ = ["Roles"]


class Roles(Base):

    def get_all_roles(self):
        """Get a list of all the roles
        `Read in Mattermost API docs (roles - GetAllRoles) <https://developers.mattermost.com/api-documentation/#/operations/GetAllRoles>`_

        """
        return self.client.get("""/api/v4/roles""")

    def get_role(self, role_id):
        """Get a role

        role_id: Role GUID

        `Read in Mattermost API docs (roles - GetRole) <https://developers.mattermost.com/api-documentation/#/operations/GetRole>`_

        """
        return self.client.get(f"/api/v4/roles/{role_id}")

    def get_role_by_name(self, role_name):
        """Get a role

        role_name: Role Name

        `Read in Mattermost API docs (roles - GetRoleByName) <https://developers.mattermost.com/api-documentation/#/operations/GetRoleByName>`_

        """
        return self.client.get(f"/api/v4/roles/name/{role_name}")

    def patch_role(self, role_id, options):
        """Patch a role

        role_id: Role GUID
        permissions: The permissions the role should grant.

        `Read in Mattermost API docs (roles - PatchRole) <https://developers.mattermost.com/api-documentation/#/operations/PatchRole>`_

        """
        return self.client.put(f"/api/v4/roles/{role_id}/patch", options=options)

    def get_roles_by_names(self, options):
        """Get a list of roles by name
        `Read in Mattermost API docs (roles - GetRolesByNames) <https://developers.mattermost.com/api-documentation/#/operations/GetRolesByNames>`_

        """
        return self.client.post("""/api/v4/roles/names""", options=options)



from ._base import Base
from typing import Any, BinaryIO

__all__ = ["Timeline"]


class Timeline(Base):

    def remove_timeline_event(self, id: str, event_id: str):
        """Remove a timeline event from the playbook run

        id: ID of the playbook run whose timeline event will be modified.
        event_id: ID of the timeline event to be deleted

        `Read in Mattermost API docs (timeline - removeTimelineEvent) <https://developers.mattermost.com/api-documentation/#/operations/removeTimelineEvent>`_

        """
        return self.client.delete(f"/plugins/playbooks/api/v0/runs/{id}/timeline/{event_id}")



from ._base import Base
from typing import Any, BinaryIO

__all__ = ["Compliance"]


class Compliance(Base):

    def create_compliance_report(self):
        """Create report
        `Read in Mattermost API docs (compliance - CreateComplianceReport) <https://developers.mattermost.com/api-documentation/#/operations/CreateComplianceReport>`_

        """
        return self.client.post("""/api/v4/compliance/reports""")

    def get_compliance_reports(self, page: int | None = 0, per_page: int | None = 60):
        """Get reports

        page: The page to select.
        per_page: The number of reports per page.

        `Read in Mattermost API docs (compliance - GetComplianceReports) <https://developers.mattermost.com/api-documentation/#/operations/GetComplianceReports>`_

        """
        __params = {"page": page, "per_page": per_page}
        return self.client.get("""/api/v4/compliance/reports""", params=__params)

    def get_compliance_report(self, report_id: str):
        """Get a report

        report_id: Compliance report GUID

        `Read in Mattermost API docs (compliance - GetComplianceReport) <https://developers.mattermost.com/api-documentation/#/operations/GetComplianceReport>`_

        """
        return self.client.get(f"/api/v4/compliance/reports/{report_id}")

    def download_compliance_report(self, report_id: str):
        """Download a report

        report_id: Compliance report GUID

        `Read in Mattermost API docs (compliance - DownloadComplianceReport) <https://developers.mattermost.com/api-documentation/#/operations/DownloadComplianceReport>`_

        """
        return self.client.get(f"/api/v4/compliance/reports/{report_id}/download")



from ._base import Base

__all__ = ["Ldap"]


class Ldap(Base):

    def migrate_auth_to_ldap(self, options=None):
        """Migrate user accounts authentication type to LDAP.

        from: The current authentication type for the matched users.
        match_field: Foreign user field name to match.
        force:

        `Read in Mattermost API docs (ldap - MigrateAuthToLdap) <https://developers.mattermost.com/api-documentation/#/operations/MigrateAuthToLdap>`_

        """
        return self.client.post("""/api/v4/users/migrate_auth/ldap""", options=options)

    def sync_ldap(self):
        """Sync with LDAP
        `Read in Mattermost API docs (ldap - SyncLdap) <https://developers.mattermost.com/api-documentation/#/operations/SyncLdap>`_

        """
        return self.client.post("""/api/v4/ldap/sync""")

    def test_ldap(self):
        """Test LDAP configuration
        `Read in Mattermost API docs (ldap - TestLdap) <https://developers.mattermost.com/api-documentation/#/operations/TestLdap>`_

        """
        return self.client.post("""/api/v4/ldap/test""")

    def test_ldap_connection(self, options):
        """Test LDAP connection with specific settings
        `Read in Mattermost API docs (ldap - TestLdapConnection) <https://developers.mattermost.com/api-documentation/#/operations/TestLdapConnection>`_

        """
        return self.client.post("""/api/v4/ldap/test_connection""", options=options)

    def test_ldap_diagnostics(self, options):
        """Test LDAP diagnostics with specific settings
        `Read in Mattermost API docs (ldap - TestLdapDiagnostics) <https://developers.mattermost.com/api-documentation/#/operations/TestLdapDiagnostics>`_

        """
        return self.client.post("""/api/v4/ldap/test_diagnostics""", options=options)

    def get_ldap_groups(self, params=None):
        """Returns a list of LDAP groups

        q: Search term
        page: The page to select.
        per_page: The number of users per page. per page.

        `Read in Mattermost API docs (ldap - GetLdapGroups) <https://developers.mattermost.com/api-documentation/#/operations/GetLdapGroups>`_

        """
        return self.client.get("""/api/v4/ldap/groups""", params=params)

    def link_ldap_group(self, remote_id):
        """Link a LDAP group

        remote_id: Group GUID

        `Read in Mattermost API docs (ldap - LinkLdapGroup) <https://developers.mattermost.com/api-documentation/#/operations/LinkLdapGroup>`_

        """
        return self.client.post(f"/api/v4/ldap/groups/{remote_id}/link")

    def migrate_id_ldap(self, options):
        """Migrate Id LDAP

        toAttribute: New IdAttribute value

        `Read in Mattermost API docs (ldap - MigrateIdLdap) <https://developers.mattermost.com/api-documentation/#/operations/MigrateIdLdap>`_

        """
        return self.client.post("""/api/v4/ldap/migrateid""", options=options)

    def upload_ldap_public_certificate(self, files, data=None):
        """Upload public certificate

        certificate: The public certificate file

        `Read in Mattermost API docs (ldap - UploadLdapPublicCertificate) <https://developers.mattermost.com/api-documentation/#/operations/UploadLdapPublicCertificate>`_

        """
        return self.client.post("""/api/v4/ldap/certificate/public""", files=files, data=data)

    def delete_ldap_public_certificate(self):
        """Remove public certificate
        `Read in Mattermost API docs (ldap - DeleteLdapPublicCertificate) <https://developers.mattermost.com/api-documentation/#/operations/DeleteLdapPublicCertificate>`_

        """
        return self.client.delete("""/api/v4/ldap/certificate/public""")

    def upload_ldap_private_certificate(self, files, data=None):
        """Upload private key

        certificate: The private key file

        `Read in Mattermost API docs (ldap - UploadLdapPrivateCertificate) <https://developers.mattermost.com/api-documentation/#/operations/UploadLdapPrivateCertificate>`_

        """
        return self.client.post("""/api/v4/ldap/certificate/private""", files=files, data=data)

    def delete_ldap_private_certificate(self):
        """Remove private key
        `Read in Mattermost API docs (ldap - DeleteLdapPrivateCertificate) <https://developers.mattermost.com/api-documentation/#/operations/DeleteLdapPrivateCertificate>`_

        """
        return self.client.delete("""/api/v4/ldap/certificate/private""")

    def add_user_to_group_syncables(self, user_id):
        """Create memberships for LDAP configured channels and teams for this user

        user_id: User Id

        `Read in Mattermost API docs (ldap - AddUserToGroupSyncables) <https://developers.mattermost.com/api-documentation/#/operations/AddUserToGroupSyncables>`_

        """
        return self.client.post(f"/api/v4/ldap/users/{user_id}/group_sync_memberships")
